@@ -1,14 +1,9 @@
 from xml.etree import ElementTree
 
-from .messages import TextMessage, ImageMessage, LocationMessage, EventMessage
+from .messages import TextMessage, ImageMessage, LocationMessage, EventMessage, LinkMessage
 from .messages import UnknownMessage
 from .utils import to_unicode
 
-MSG_TYPE_TEXT = 'text'
-MSG_TYPE_LOCATION = 'location'
-MSG_TYPE_IMAGE = 'image'
-MSG_TYPE_EVENT = 'event'
-
 
 def parse_user_msg(xml):
     """
@@ -31,24 +26,26 @@ def parse_user_msg(xml):
         fromuser=fromuser,
         time=create_at
     )
-    if msg_type == MSG_TYPE_TEXT:
+    if msg_type == 'text':
         msg["content"] = _msg.get('Content')
         return TextMessage(**msg)
-    elif msg_type == MSG_TYPE_LOCATION:
+    elif msg_type == 'location':
         msg["location_x"] = _msg.get('Location_X')
         msg["location_y"] = _msg.get('Location_Y')
         msg["scale"] = int(_msg.get('Scale'))
         msg["label"] = _msg.get('Label')
         return LocationMessage(**msg)
-    elif msg_type == MSG_TYPE_IMAGE:
+    elif msg_type == 'image':
         msg["img"] = _msg.get('PicUrl')
         return ImageMessage(**msg)
-    elif msg_type == MSG_TYPE_EVENT:
+    elif msg_type == 'event':
         msg["type"] = _msg.get('Event').lower()
         if msg["type"] == "location":
             msg["latitude"] = _msg.get('Latitude')
             msg["longitude"] = _msg.get('Longitude')
             msg["precision"] = _msg.get('Precision')
         return EventMessage(**msg)
+    elif msg_type == 'link':
+        return LinkMessage(**msg)
     else:
         return UnknownMessage(xml)
